==> nextcloud-21.0.0-9-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/workflowengine/l10n/zh_HK.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "指定的操作無效",
    "The given regular expression is invalid" : "指定的規則表達式無效",
    "The given file size is invalid" : "指定的檔案大小無效",
    "The given tag id is invalid" : "指定的標籤 Id無效",
    "The given IP range is invalid" : "指定的IP 範圍無效",
    "The given IP range is not valid for IPv4" : "指定的IP範圍不是有效的IPv4",
    "The given IP range is not valid for IPv6" : "指定的IP範圍不是有效的IPv6",
    "The given time span is invalid" : "指定的時間範圍無效",
    "The given start time is invalid" : "指定的開始時間無效",
    "The given end time is invalid" : "指定的結束時間無效",
    "The given group does not exist" : "指定的群組不存在",
    "File" : "檔案",
    "File created" : "檔案建立",
    "File updated" : "檔案更新",
    "File renamed" : "檔案重新命名",
    "File deleted" : "檔案刪除",
    "File accessed" : "檔案存取",
    "File copied" : "檔案複製",
    "Tag assigned" : "分派標籤",
    "Someone" : "某人",
    "%s created %s" : "%s 建立 %s",
    "%s modified %s" : "%s 修改 %s",
    "%s deleted %s" : "%s 刪除 %s",
    "%s accessed %s" : "%s 存取 %s",
    "%s renamed %s" : "%s 重新命名 %s",
    "%s copied %s" : "%s 複製 %s",
    "%s assigned %s to %s" : "%s 分派 %s 給 %s",
    "Operation #%s does not exist" : "操作 #%s 不存在",
    "Entity %s does not exist" : "實體 %s 不存在",
    "Entity %s is invalid" : "實體 %s 無效",
    "No events are chosen." : "未選擇事件。",
    "Entity %s has no event %s" : "實體 %s 沒有事件 %s",
    "Operation %s does not exist" : "操作 %s 不存在",
    "Operation %s is invalid" : "操作 #%s 無效",
    "The provided operation data is too long" : "指定的操作數據太長",
    "Check %s does not exist" : "檢查 %s 不存在",
    "Check %s is invalid" : "檢查 %s 無效",
    "The provided check value is too long" : "指定的檢查數據太長",
    "Check #%s does not exist" : "檢查 #%s 不存在",
    "Check %s is invalid or does not exist" : "檢查 %s 無效或不存在",
    "Flow" : "流程",
    "Nextcloud workflow engine" : "Nextcloud 工作流程引擎",
    "Select a filter" : "選擇過濾器",
    "Select a comparator" : "選擇比較器",
    "Select a file type" : "選擇檔案類型",
    "e.g. httpd/unix-directory" : "例如 httpd/unix-directory",
    "Folder" : "資料夾",
    "Images" : "圖片",
    "Office documents" : "Microsoft Office 文件",
    "PDF documents" : "PDF 文件",
    "Custom mimetype" : "自訂 mimetype",
    "Select a tag" : "選擇標籤",
    "No results" : "沒有符合搜尋的項目",
    "%s (invisible)" : "%s （隱藏）",
    "%s (restricted)" : "%s （受限）",
    "Predefined URLs" : "預定義網址",
    "Files WebDAV" : "檔案 WebDAV",
    "Others" : "其他",
    "Custom URL" : "自訂 URL",
    "Select a user agent" : "選擇用戶 agent",
    "Android client" : "Android 客戶端",
    "iOS client" : "iOS 客戶端",
    "Desktop client" : "桌面客戶端",
    "Thunderbird & Outlook addons" : "Thunderbird & Outlook 插件",
    "Custom user agent" : "自訂用戶 agent",
    "At least one event must be selected" : "必須選擇至少一個活動",
    "and" : "及",
    "Cancel" : "取消",
    "Delete" : "刪除",
    "The configuration is invalid" : "配置無效",
    "Active" : "啟動",
    "Save" : "儲存",
    "Browse the app store" : "瀏覽應用程式商店",
    "Show less" : "顯示較少",
    "Show more" : "顯示更多",
    "matches" : "匹配",
    "does not match" : "不能匹配",
    "is" : "是",
    "is not" : "不是",
    "File name" : "檔案名稱",
    "File MIME type" : "檔案MIME類型",
    "File size (upload)" : "檔案大小(上傳)",
    "less" : "更少",
    "less or equals" : "小於或等於",
    "greater or equals" : "大於或等於",
    "greater" : "更大",
    "Request remote address" : "請求遠端地址",
    "matches IPv4" : "匹配 IPv4",
    "does not match IPv4" : "不能匹配 IPv4",
    "matches IPv6" : "匹配 IPv6",
    "does not match IPv6" : "不能匹配 IPv6",
    "File system tag" : "檔案系統標籤",
    "is tagged with" : "標記為",
    "is not tagged with" : "没有標記為",
    "Request URL" : "請求網址",
    "Request time" : "請求時間",
    "between" : "之間",
    "not between" : "皆非",
    "Request user agent" : "請求用戶代理",
    "User group membership" : "使用者成員關係",
    "is member of" : "是成員來自",
    "is not member of" : "不是成員來自"
},
"nplurals=1; plural=0;");

==> nextcloud-22.0.0-2-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/workflowengine/l10n/zh_HK.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "指定的操作無效",
    "The given regular expression is invalid" : "指定的規則表達式無效",
    "The given file size is invalid" : "指定的檔案大小無效",
    "The given tag id is invalid" : "指定的標籤 Id無效",
    "The given IP range is invalid" : "指定的IP 範圍無效",
    "The given IP range is not valid for IPv4" : "指定的IP範圍不是有效的IPv4",
    "The given IP range is not valid for IPv6" : "指定的IP範圍不是有效的IPv6",
    "The given time span is invalid" : "指定的時間範圍無效",
    "The given start time is invalid" : "指定的開始時間無效",
    "The given end time is invalid" : "指定的結束時間無效",
    "The given group does not exist" : "指定的群組不存在",
    "File" : "檔案",
    "File created" : "檔案建立",
    "File updated" : "檔案更新",
    "File renamed" : "檔案重新命名",
    "File deleted" : "檔案刪除",
    "File accessed" : "檔案存取",
    "File copied" : "檔案複製",
    "Tag assigned" : "分派標籤",
    "Someone" : "某人",
    "%s created %s" : "%s 建立 %s",
    "%s modified %s" : "%s 修改 %s",
    "%s deleted %s" : "%s 刪除 %s",
    "%s accessed %s" : "%s 存取 %s",
    "%s renamed %s" : "%s 重新命名 %s",
    "%s copied %s" : "%s 複製 %s",
    "%s assigned %s to %s" : "%s 分派 %s 給 %s",
    "Operation #%s does not exist" : "操作 #%s 不存在",
    "Entity %s does not exist" : "實體 %s 不存在",
    "Entity %s is invalid" : "實體 %s 無效",
    "No events are chosen." : "未選擇事件。",
    "Entity %s has no event %s" : "實體 %s 沒有事件 %s",
    "Operation %s does not exist" : "操作 %s 不存在",
    "Operation %s is invalid" : "操作 #%s 無效",
    "At least one check needs to be provided" : "至少需要提供一個檢查規則",
    "The provided operation data is too long" : "指定的操作數據太長",
    "Invalid check provided" : "提供了無效的檢查規則",
    "Check %s does not exist" : "檢查 %s 不存在",
    "Check %s is invalid" : "檢查 %s 無效",
    "Check %s is not allowed with this entity" : "此實體不允許使用檢查規則 %s",
    "The provided check value is too long" : "指定的檢查數據太長",
    "Check #%s does not exist" : "檢查 #%s 不存在",
    "Check %s is invalid or does not exist" : "檢查 %s 無效或不存在",
    "Flow" : "流程",
    "Nextcloud workflow engine" : "Nextcloud 工作流程引擎",
    "Select a filter" : "選擇過濾器",
    "Select a comparator" : "選擇比較器",
    "Select a file type" : "選擇檔案類型",
    "e.g. httpd/unix-directory" : "例如 httpd/unix-directory",
    "Folder" : "資料夾",
    "Images" : "圖片",
    "Office documents" : "Microsoft Office 文件",
    "PDF documents" : "PDF 文件",
    "Custom mimetype" : "自訂 mimetype",
    "Select a tag" : "選擇標籤",
    "No results" : "沒有符合搜尋的項目",
    "%s (invisible)" : "%s （隱藏）",
    "%s (restricted)" : "%s （受限）",
    "Please enter a valid time span" : "請輸入有效的時間跨度",
    "Select a request URL" : "選擇一個請求URL",
    "Predefined URLs" : "預定義網址",
    "Files WebDAV" : "檔案 WebDAV",
    "Others" : "其他",
    "Custom URL" : "自訂 URL",
    "Select a user agent" : "選擇用戶 agent",
    "Android client" : "Android 客戶端",
    "iOS client" : "iOS 客戶端",
    "Desktop client" : "桌面客戶端",
    "Thunderbird & Outlook addons" : "Thunderbird & Outlook 插件",
    "Custom user agent" : "自訂 user agent",
    "At least one event must be selected" : "必須選擇至少一個活動",
    "Add new flow" : "添加新流程",
    "When" : "時間",
    "and" : "及",
    "Cancel" : "取消",
    "Delete" : "刪除",
    "The configuration is invalid" : "配置無效",
    "Active" : "啟動",
    "Save" : "儲存",
    "Available flows" : "可用的流程",
    "For details on how to write your own flow, check out the development documentation." : "有關如何編寫自己的流程的詳細信息，請查看開發說明文件。",
    "More flows" : "更多流程",
    "Browse the App Store" : "瀏覽 App Store",
    "Show less" : "顯示較少",
    "Show more" : "顯示更多",
    "Configured flows" : "配置流程",
    "Your flows" : "您的流程",
    "matches" : "匹配",
    "does not match" : "不能匹配",
    "is" : "是",
    "is not" : "不是",
    "File name" : "檔案名稱",
    "File MIME type" : "檔案MIME類型",
    "File size (upload)" : "檔案大小(上傳)",
    "less" : "更少",
    "less or equals" : "小於或等於",
    "greater or equals" : "大於或等於",
    "greater" : "更大",
    "Request remote address" : "請求遠端地址",
    "matches IPv4" : "匹配 IPv4",
    "does not match IPv4" : "不能匹配 IPv4",
    "matches IPv6" : "匹配 IPv6",
    "does not match IPv6" : "不能匹配 IPv6",
    "File system tag" : "檔案系統標籤",
    "is tagged with" : "標記為",
    "is not tagged with" : "没有標記為",
    "Request URL" : "請求網址",
    "Request time" : "請求時間",
    "between" : "介於",
    "not between" : "皆非",
    "Request user agent" : "請求 user agent",
    "User group membership" : "用戶群組成員身分",
    "is member of" : "是以下群組的成員：",
    "is not member of" : "非以下群組的成員：",
    "Browse the app store" : "瀏覽應用程式商店"
},
"nplurals=1; plural=0;");
